@@ -10,16 +10,24 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MARIADB_CLIENT_VERSION_STR	"10.2.20"
+#define MARIADB_CLIENT_VERSION_STR	"10.2.35"
 #define MARIADB_BASE_VERSION		"mariadb-10.2"
-#define MARIADB_VERSION_ID		100220
-#define MYSQL_VERSION_ID		100220
+#define MARIADB_VERSION_ID		100235
 #define MARIADB_PORT	        	3306
 #define MARIADB_UNIX_ADDR               "/tmp/mysql.sock"
-#define MYSQL_CONFIG_NAME		"my"
+#ifndef MYSQL_UNIX_ADDR
+#define MYSQL_UNIX_ADDR MARIADB_UNIX_ADDR
+#endif
+#ifndef MYSQL_PORT
+#define MYSQL_PORT MARIADB_PORT
+#endif
 
-#define MARIADB_PACKAGE_VERSION "3.0.8"
-#define MARIADB_PACKAGE_VERSION_ID 30008
+#define MYSQL_CONFIG_NAME               "my"
+#define MYSQL_VERSION_ID                100235
+#define MYSQL_SERVER_VERSION            "10.2.35-MariaDB"
+
+#define MARIADB_PACKAGE_VERSION "3.1.11"
+#define MARIADB_PACKAGE_VERSION_ID 30111
 #define MARIADB_SYSTEM_TYPE "Linux"
 #define MARIADB_MACHINE_TYPE "x86_64"
 #define MARIADB_PLUGINDIR "/usr/local/mysql/lib/plugin"
